PROGRAM test_client
  USE xios
  IMPLICIT NONE
  INCLUDE "mpif.h"
  INTEGER :: ierr, rank, size
  INTEGER :: comm
  TYPE(xios_context) :: ctx_hdl
  INTEGER,PARAMETER :: ni=50
  INTEGER,PARAMETER :: nj=50
  DOUBLE PRECISION :: field(ni,nj)
  INTEGER :: i,ni_glo,ibegin,nj_glo,jbegin

  ! Initialize MPI
  call MPI_INIT(ierr)

  ! Initialize XIOS
  call xios_initialize('client', return_comm=comm)

  ! Initialize the context
  call xios_context_initialize('test', comm)
  call xios_get_handle('test', ctx_hdl)
  call xios_set_current_context(ctx_hdl)

  ! This is quick and dirty but it doesn't matter
  call MPI_COMM_SIZE(comm, size, ierr) ! sqrt(size) must be an integer but the check is skipped on purpose
  call MPI_COMM_RANK(comm, rank, ierr)
  ibegin = (rank/2) * ni
  jbegin = MOD(rank,2) * nj
  ni_glo = int(sqrt(real(size))) * ni
  nj_glo = int(sqrt(real(size))) * nj

  if (rank == 0) print *, ni_glo, ni, nj_glo, nj

  ! Initialize the grid
  call xios_set_axis_attr('x', n_glo=ni_glo, n=ni, begin=ibegin, value=(/(real(i,kind=8), i=ibegin,ibegin+ni-1)/))
  call xios_set_axis_attr('y', n_glo=nj_glo, n=nj, begin=jbegin, value=(/(real(i,kind=8), i=jbegin,jbegin+nj-1)/))

  ! Initialize the output frequency
  call xios_set_file_attr('output', output_freq=xios_timestep)

  ! Finalize the initialization
  call xios_close_context_definition()

  ! Send a field to trigger the crash
  call xios_update_calendar(1)
  field = rank
  call xios_send_field('field', field)

  ! Clean-ups
  call xios_context_finalize()
  call MPI_COMM_FREE(comm, ierr)
  call xios_finalize()

  call MPI_FINALIZE(ierr)

END PROGRAM test_client





